Package: toolero
Title: A Toolkit for Research Workflows
Version: 0.3.0
Authors@R: 
    person("Erwin", "Lares", , "erwin.lares@wisc.edu", role = c("aut", "cre"),
           comment = c(ORCID = "0000-0002-3284-828X"))
Description: Provides utility functions to help researchers implement best
    practices for their coding projects. Includes tools for reading and
    cleaning data files, initializing R projects with a standard folder
    structure, creating Quarto documents from a reproducible template,
    detecting the execution context across interactive, Quarto, and
    script-based workflows, and splitting data frames into group-level
    output files.
License: MIT + file LICENSE
Depends: R (>= 4.2.0)
Encoding: UTF-8
Language: en-US
RoxygenNote: 7.3.2
Suggests: knitr, rmarkdown, spelling, testthat (>= 3.0.0),
Config/testthat/edition: 3
Imports: cli, fs, glue, janitor, purrr, readr, renv, tibble, usethis,
        yaml, rlang, rvest, xml2, quarto, withr
URL: https://github.com/erwinlares/toolero,
        https://erwinlares.github.io/toolero/
BugReports: https://github.com/erwinlares/toolero/issues
VignetteBuilder: knitr
NeedsCompilation: no
Packaged: 2026-04-27 15:23:42 UTC; lares
Author: Erwin Lares [aut, cre] (ORCID: <https://orcid.org/0000-0002-3284-828X>)
Maintainer: Erwin Lares <erwin.lares@wisc.edu>
Repository: CRAN
Date/Publication: 2026-04-27 18:40:02 UTC
Built: R 4.6.0; ; 2026-04-27 21:40:06 UTC; unix
